summaryrefslogtreecommitdiffstats
path: root/chalk/plugins/viewplugins/screenshot/ksnapshot.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'chalk/plugins/viewplugins/screenshot/ksnapshot.cpp')
-rw-r--r--chalk/plugins/viewplugins/screenshot/ksnapshot.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/chalk/plugins/viewplugins/screenshot/ksnapshot.cpp b/chalk/plugins/viewplugins/screenshot/ksnapshot.cpp
index f9887821..dad0ee01 100644
--- a/chalk/plugins/viewplugins/screenshot/ksnapshot.cpp
+++ b/chalk/plugins/viewplugins/screenshot/ksnapshot.cpp
@@ -413,15 +413,15 @@ void KSnapshot::performGrab()
contents += TQRegion( w - border, 0, border, h );
}
- //Get the tqmasked away area.
- TQRegion tqmaskedAway = bbox - contents;
- TQMemArray<TQRect> tqmaskedAwayRects = tqmaskedAway.rects();
+ //Get the masked away area.
+ TQRegion maskedAway = bbox - contents;
+ TQMemArray<TQRect> maskedAwayRects = maskedAway.rects();
//Construct a bitmap tqmask from the rectangles
TQPainter p(&tqmask);
p.fillRect(0, 0, w, h, TQt::color1);
- for (uint pos = 0; pos < tqmaskedAwayRects.count(); pos++)
- p.fillRect(tqmaskedAwayRects[pos], TQt::color0);
+ for (uint pos = 0; pos < maskedAwayRects.count(); pos++)
+ p.fillRect(maskedAwayRects[pos], TQt::color0);
p.end();
snapshot.setMask(tqmask);